from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from . import models


class UserAdmin(admin.ModelAdmin):
    list_display = ('username', 'email', 'is_active', 'is_staff', 'is_admin', 'is_superuser')
    list_filter = ('is_active', 'is_staff', 'is_admin', 'is_superuser')
    search_fields = ('username', 'email')
    ordering = ('username',)

    fieldsets = (
        (None, {'fields': ('username', 'email', 'password')}),
        (_('Permissions'), {'fields': ('is_active', 'is_staff', 'is_admin', 'is_superuser')}),
        (_('Important dates'), {'fields': ('last_login', 'date_joined')}),
    )

    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('username', 'email', 'password1', 'password2'),
        }),
    )


admin.site.register(models.User, UserAdmin)



from django.shortcuts import redirect
from django.contrib.auth import login
from django.views import generic
from django.urls import reverse_lazy

from .models import User
from .forms import UserCreationForm


class RegisterView(generic.CreateView):
    model = User
    form_class = UserCreationForm

    def form_valid(self, form):
        user = form.save()
        login(self.request, user)
        return redirect(reverse_lazy('home'))



from django.contrib.auth.forms import UserCreationForm
from .models import User


class UserCreationForm(UserCreationForm):

    class Meta:
        model = User
        fields = ['email', 'username', 'password1', 'password2']



from rest_framework import serializers
from .models import User


class UserSerializer(serializers.ModelSerializer):
    class Meta:
        model = User
        fields = ['id', 'username', 'email', 'date_joined', 'last_login', 'is_active', 'is_staff', 'is_admin', 'is_superuser']



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

extras_require = {
    "rest_framework": ["djangorestframework>=3.12"],
    "filters": ["django-filter>=2.4"],
}

setup(
    name='django-email-accounts',
    version='0.2.0',
    author='Fathi Abdelmalek',
    author_email='abdelmalek.fathi.2001@gmail.com',
    description='A Django app for user management with email-based authentication.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/fathiabdelmalek/django-email-accounts',
    packages=find_packages(),
    classifiers=[
        "Development Status :: 1 - Planning",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    python_requires=">=3.7",
    install_requires=[
        'Django>=3.2.0',
    ],
    extras_require=extras_require,
)



from django.db import models
from django.contrib.auth.models import AbstractBaseUser, BaseUserManager


class UserManager(BaseUserManager):
    def create_user(self, email, username, password=None):
        if not email:
            raise ValueError("You must enter email address")
        if not username:
            raise ValueError("You must enter username")
        user = self.model(
            email=self.normalize_email(email),
            username=username,
        )
        user.set_password(password)
        user.save(using=self._db)
        return user

    def create_superuser(self, email, username, password):
        user = self.create_user(
            email=self.normalize_email(email),
            username=username,
            password=password,
        )
        user.is_superuser = True
        user.is_admin = True
        user.is_staff = True
        user.save(using=self._db)
        return user


class User(AbstractBaseUser):
    email = models.EmailField(verbose_name="email", max_length=254, unique=True)
    username = models.CharField(verbose_name="user name", max_length=50, unique=True)
    date_joined = models.DateTimeField(verbose_name="join date", auto_now_add=True)
    last_login = models.DateTimeField(verbose_name="last login", auto_now=True)
    is_active = models.BooleanField(default=True)
    is_staff = models.BooleanField(default=False)
    is_admin = models.BooleanField(default=False)
    is_superuser = models.BooleanField(default=False)

    USERNAME_FIELD = 'email'
    REQUIRED_FIELDS = ['username']

    objects = UserManager()

    def __str__(self):
        return self.username

    def has_perm(self, perm, obj=None):
        return self.is_admin

    def has_module_perms(self, app_label):
        return True



import django_filters
from .models import User


class UserFilter(django_filters.FilterSet):
    class Meta:
        model = User
        fields = {
            'username': ['exact', 'icontains'],
            'email': ['exact', 'icontains'],
        }
